Client class

Annotations
  • @JsonSerializable.new(includeIfNull: false)

Constructors

Client({String? firstName, String? lastName, DateTime? createdAt, DateTime? updatedAt, String? id, String? email, List<String>? roles})
const
Client.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime?
final
email String?
final
firstName String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
lastName String?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
roles List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool
If set to true, the toString method will be overridden to output this instance's props.
no setter
updatedAt DateTime?
final

Methods

copyWith({String? firstName, String? lastName, DateTime? createdAt, DateTime? updatedAt, String? id, String? email, List<String>? roles}) Client
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited