AuthPayload class
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
- AuthPayload({String? email, String? phone, required String password, String? frontUrl, String? accountActivationMethod})
-
const
-
AuthPayload.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountActivationMethod → String?
-
final
- email → String?
-
final
- frontUrl → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- password → String
-
final
- phone → String?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
If set to
true, the toString method will be overridden to output this instance's props.no setter
Methods
-
copyWith(
{String? email, String? phone, String? password, String? frontUrl, String? accountActivationMethod}) → AuthPayload -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited