Pagination<T> class
- Annotations
-
- @JsonSerializable.new(genericArgumentFactories: true)
Constructors
-
Pagination({int? total, int? totalPages, int? currentPage, List<
T> ? items}) -
const
-
Pagination.fromJson(Map<
String, dynamic> json, T fromJsonT(Object? json)) -
factory
Properties
- currentPage → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
T> ? -
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, the toString method will be overridden to output this instance's props.no setter - total → int?
-
final
- totalPages → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
Pagination< T> instance, Object? toJsonT(T value)) → Map<String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited