PaginationPayload class
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
- PaginationPayload({int? page = 1, int? limit = 10, int? sort = 1})
-
const
-
PaginationPayload.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
final
- page → int?
-
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sort → int?
-
final
- stringify → bool
-
If set to
true, the toString method will be overridden to output this instance's props.no setter
Methods
-
copyWith(
{int? page, int? limit, int? sort}) → PaginationPayload -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited