SharedPref class

Constructors

SharedPref()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
prefs ↔ SharedPreferences?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteRefreshToken() Future<bool?>
deleteToken() Future<bool?>
init() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readRefreshToken() Future<String>
readToken() Future<String>
saveRefreshToken(String token) Future<bool?>
saveToken(String token) Future<bool?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

userRefreshToken → const String
userToken → const String