Aplication class
- Annotations
-
- @JsonSerializable.new(includeIfNull: false)
Constructors
-
Aplication({List? accountActivationMethod, String? name, String? authType, List<
String> ? authFields, List<String> ? passwordRecoveryMethod, bool? isActive, bool? allowRegister, Client? client, DateTime? createdAt, DateTime? updatedAt, String? gClientId, String? gClientSecret, List<String> ? authSocial, String? fAppId, String? fAppSecret, String? id}) -
const
-
Aplication.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountActivationMethod → List?
-
final
- allowRegister → bool?
-
final
-
authFields
→ List<
String> ? -
final
-
authSocial
→ List<
String> ? -
final
- authType → String?
-
final
- client → Client?
-
final
- createdAt → DateTime?
-
final
- fAppId → String?
-
final
- fAppSecret → String?
-
final
- gClientId → String?
-
final
- gClientSecret → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- isActive → bool?
-
final
- name → String?
-
final
-
passwordRecoveryMethod
→ List<
String> ? -
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool
-
If set to
true, the toString method will be overridden to output this instance's props.no setter - updatedAt → DateTime?
-
final
Methods
-
copyWith(
{List? accountActivationMethod, String? name, String? authType, List< String> ? authFields, List<String> ? passwordRecoveryMethod, bool? isActive, bool? allowRegister, Client? client, DateTime? createdAt, DateTime? updatedAt, String? gClientId, String? gClientSecret, List<String> ? authSocial, String? fAppId, String? fAppSecret, String? id}) → Aplication -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited